package com.miya.ali;


import com.miya.Demo;
import com.miya.common.util.SessionClient;

import java.sql.SQLException;

public class MiyaPayLogSLSToHBase {

    private static final String CREATE_SOURCE_SQL =
            "CREATE TABLE source_aliyun_sls_miyapay_log (\n" +
                    "  __source__ STRING,\n" +
                    "  __hostname__ STRING,\n" +
                    "  __path__ STRING,\n" +
                    "  __receive_time__ STRING,\n" +
                    "  consume_time STRING,\n" +
                    "  `ip` STRING,\n" +
                    "  market_code STRING,\n" +
                    "  merchant_code STRING,\n" +
                    "  `message` STRING,\n" +
                    "  message_type STRING,\n" +
                    "  pay_type STRING,\n" +
                    "  paymentplatform STRING,\n" +
                    "  `time` STRING,\n" +
                    "  trade_no STRING,\n" +
                    "  trade_step STRING,\n" +
                    "  trade_type STRING,\n" +
                    "  uuid_string STRING\n" +
                    ") WITH (\n" +
                    "'connector' = 'kafka',\n" +
                    "'topic' = 'sls-miyapay-log',\n" +
                    "'properties.bootstrap.servers' = '10.0.1.227:9092,10.0.1.226:9092,10.0.1.228:9092',\n" +
                    "'properties.group.id' = 'testGroup',\n" +
                    "'scan.startup.mode' = 'latest-offset','format' = 'json'\n" +
                    ")\n";

    private static final String CREATE_SINK_SQL = "CREATE TABLE sink_huawei_hbase_sls_miyapay_log (\n" +
            " rowkey STRING,\n" +
            " f ROW<source_ip STRING,\n" +
            "                               hostname         STRING,\n" +
            "                               path      STRING,\n" +
            "                               receive_time           STRING,\n" +
            "                               consume_time  STRING,\n" +
            "                               ip     STRING,\n" +
            "                               market_code        STRING,\n" +
            "                               merchant_code           STRING,\n" +
            "                               message        STRING,\n" +
            "                               message_type           STRING,\n" +
            "                               pay_type       STRING,\n" +
            "                               paymentplatform   STRING,\n" +
            "                               trade_time   STRING,\n" +
            "                               trade_no   STRING,\n" +
            "                               trade_step    STRING,\n" +
            "                               trade_type          STRING,\n" +
            "                               uuid_string        STRING,\n" +
            "                               pt_day        STRING>,\n" +
            " PRIMARY KEY (rowkey) NOT ENFORCED\n" +
            ") WITH (\n" +
            " 'connector' = 'hbase-2.2',\n" +
            " 'table-name' = 'original:sls_miyapay_log',\n" +
            " 'zookeeper.quorum' = '172.16.130.64:2181,172.16.128.15:2181,172.16.129.113:2181'" +
            ")";

    private static final String CREATE_JOB_SQL = "insert into sink_huawei_hbase_sls_miyapay_log\n" +
            "SELECT\n" +
            "   CONCAT( CAST( (MOD(CAST(DATE_FORMAT(trade_time,'yyyyMMdd') AS INT),10)) AS  STRING ) , '~' , DATE_FORMAT(trade_time,'yyyyMMdd'),'~' , uuid_string) as rowkey,\n" +
            "   ROW(\n" +
            "        source_ip,\n" +
            "        hostname,\n" +
            "        path,\n" +
            "        receive_time,\n" +
            "        consume_time,\n" +
            "        ip,\n" +
            "        market_code,\n" +
            "        merchant_code,\n" +
            "        message,\n" +
            "        message_type,\n" +
            "        pay_type,\n" +
            "        paymentplatform,\n" +
            "        trade_time,\n" +
            "        trade_no,\n" +
            "        trade_step,\n" +
            "        trade_type,\n" +
            "        uuid_string,\n" +
            "        pt_day) as f\n" +
            "from (SELECT \n" +
            "  __source__ AS source_ip,\n" +
            "  __hostname__ AS hostname,\n" +
            "  __path__ AS path,\n" +
            "  __receive_time__ AS receive_time,\n" +
            "  consume_time,\n" +
            "  `ip`,\n" +
            "  market_code,\n" +
            "  merchant_code,\n" +
            "  `message`,\n" +
            "  message_type,\n" +
            "  pay_type,\n" +
            "  paymentplatform,\n" +
            "  `time` AS trade_time,\n" +
            "  trade_no,\n" +
            "  trade_step,\n" +
            "  trade_type,\n" +
            "  uuid_string,\n" +
            "  DATE_FORMAT(`time`, 'yyyyMMdd') AS pt_day\n" +
            "FROM\n" +
            "  source_aliyun_sls_miyapay_log\n" +
            "WHERE\n" +
            "  trade_no <> 'null')\n";


    public static void main(String[] args) throws Exception {
        SessionClient session = new SessionClient(new Demo().getClass().getName(),"123.60.47.52", 8083, "streaming");
        kafka2kafka(session);
        session.close();
    }


    private static void kafka2kafka(SessionClient session) throws SQLException {
         System.out.println(session.submitStatement(CREATE_SOURCE_SQL).getResults());
         System.out.println(session.submitStatement(CREATE_SINK_SQL).getResults());
        System.out.println(session.submitStatement(CREATE_JOB_SQL).getResults());
    }
}
